@@ -43,34 +43,37 @@ def create_github_pr(repo: str, head_branch: str, title: str, body: str, base: s
             head=head_branch,
             base=base
         )
-        print(f"✅ Created PR #{pr.number} in {repo}: {pr.html_url}")
+        print(f"✅ Created PR #{pr.number}: {pr.html_url}")
 
         if issue_num:
             issue = repo_obj.get_issue(number=issue_num)
             issue.create_comment(f"A PR has been created for this sync: {pr.html_url}")
-            issue.edit(state="closed")
-            print(f"💬 Commented on and closed issue #{issue_num}.")
 
         return pr.number, pr.html_url
 
     except Exception as e:
-        print(f"❌ Failed to create PR in {repo}: {e}")
+        print(f"❌ Failed to create PR: {e}")
         raise
 
 
+
 def push_branch(branch_name: str):
-    """
-    Create and push a branch with committed changes.
-    """
     try:
-        subprocess.run(["git", "checkout", "-b", branch_name], check=True)
+        subprocess.run(["git", "checkout", "-B", branch_name], check=True)
         subprocess.run(["git", "config", "user.email", "github-actions@users.noreply.github.com"], check=True)
         subprocess.run(["git", "config", "user.name", "github-actions"], check=True)
         subprocess.run(["git", "add", "."], check=True)
-        subprocess.run(["git", "commit", "-m", f"Update policy from AWS: {branch_name}"], check=True)
-        subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
+        subprocess.run(["git", "commit", "-m", f"Update policy: {branch_name}"], check=True)
+
+        try:
+            subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
+        except subprocess.CalledProcessError:
+            typer.echo("⚠️ Push failed. Trying to pull + re-push...")
+            subprocess.run(["git", "pull", "--rebase", "origin", branch_name], check=True)
+            subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
 
         typer.echo(f"✅ Pushed branch {branch_name} to origin.")
     except subprocess.CalledProcessError as e:
         typer.echo(f"❌ Git command failed: {e}")
         raise typer.Exit(1)
+
